package cn.cecep.talroad.service;
import java.util.List;
import java.util.Map;

import cn.cecep.talroad.vo.BMainThreeSupervisionEnforcVo;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.cecep.talroad.domain.BMainThreeSupervisionEnforc;

/**
 * 三监联动执法信息Service接口
 *
 * @author szhpt
 * @date 2023-03-29*/
public interface IBMainThreeSupervisionEnforcService extends  IService<BMainThreeSupervisionEnforc>
{
    /**
     * 查询三监联动执法信息列表
     *
     * @param bMainThreeSupervisionEnforc 三监联动执法信息
     * @return 三监联动执法信息集合
     */
    public List<BMainThreeSupervisionEnforc> selectBMainThreeSupervisionEnforcList(BMainThreeSupervisionEnforc bMainThreeSupervisionEnforc);

    BMainThreeSupervisionEnforcVo selectById(String taskId);

    Object xianheGet(Map string,String token);

    Object xianheGetInfo(String taskId, String authorization);

    Object xianheGetTaskAccount(Map data,String token);

    Object xianheGetTaskInfo(String taskId, String authorization);
    Object xianheGetCityCodeList(String pid, String authorization);

    Object xianheGetCheckTaskAccount(Map data, String authorization);

    Object xianheGetAllUrl(String url,String method, String param, String authorization);
}
